@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::perl::str::str_normalize_perl_modname;
 
-our $DATE = '2016-07-25'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2016-08-03'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -26,7 +26,7 @@ sub coerce {
     $res->{expr_match} = "1";
     $res->{expr_coerce} = join(
         "",
-        "do { (my \$tmp = $dt) =~ s{(?<!:):(?!:)|-|/|\\.}{::}g; \$tmp }",
+        "do { my \$tmp = $dt; \$tmp = \$1 if \$tmp =~ m!\\A(\\w+(?:/\\w+)*)\.pm\\z!; \$tmp =~ s!::?|/|\\.!::!g; \$tmp }",
     );
 
     $res;
@@ -47,7 +47,7 @@ Data::Sah::Coerce::perl::str::str_normalize_perl_modname - Coerce perl::modname
 
 =head1 VERSION
 
-This document describes version 0.004 of Data::Sah::Coerce::perl::str::str_normalize_perl_modname (from Perl distribution Sah-Schemas-Perl), released on 2016-07-25.
+This document describes version 0.005 of Data::Sah::Coerce::perl::str::str_normalize_perl_modname (from Perl distribution Sah-Schemas-Perl), released on 2016-08-03.
 
 =head1 DESCRIPTION
 
@@ -55,6 +55,7 @@ This rule can normalize strings in the form of:
 
  Foo:Bar
  Foo-Bar
+ Foo/Bar.pm
  Foo/Bar
  Foo.Bar
 
